@@ -9,19 +9,34 @@
 #include <QQmlApplicationEngine>
 #include <QCommandLineParser>
 #include <QQmlContext>
+#include <QQuickStyle>
+#include <QStandardPaths>
 
 #include <KAboutData>
 #include <KLocalizedString>
 #include <KLocalizedContext>
+#include <KColorSchemeManager>
 
 int main(int argc, char* argv[])
 {
+    QIcon::setFallbackThemeName(QStringLiteral("breeze"));
+
     QApplication app(argc, argv);
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("kdeconnect")));
     KAboutData aboutData(QStringLiteral("kdeconnect.app"), i18n("KDE Connect"), QStringLiteral("1.0"), i18n("KDE Connect"), KAboutLicense::GPL, i18n("(c) 2015, Aleix Pol Gonzalez"));
     aboutData.addAuthor(i18n("Aleix Pol Gonzalez"), i18n("Maintainer"), QStringLiteral("aleixpol@kde.org"));
     KAboutData::setApplicationData(aboutData);
 
+#ifdef Q_OS_WIN
+    KColorSchemeManager manager;
+    QApplication::setStyle(QStringLiteral("breeze"));
+#endif
+
+    // Default to org.kde.desktop style unless the user forces another style
+    if (qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE")) {
+        QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
+    }
+
     {
         QCommandLineParser parser;
         aboutData.setupCommandLine(&parser);
